@@ -382,7 +382,8 @@ plot.sobolroauc <- function(x, ylim = c(0, 1), ...) {
   }
 }
 
-ggplot.sobolroauc <- function(x, ylim = c(0, 1), ...) {
+ggplot.sobolroauc <- function(data, mapping = aes(), ylim = c(0,1), ..., environment = parent.frame()) {
+  x <- data
   
   if (!is.null(x$y)) {
     if (x$order==1){
