@@ -163,7 +163,8 @@ plot.soboltouati <- function(x, ylim = c(0, 1), ...) {
   }
 }
 
-ggplot.soboltouati <- function(x, ylim = c(0, 1), ...) {
+ggplot.soboltouati <- function(data, mapping = aes(), ylim = c(0,1), ..., environment = parent.frame()) {
+  x <- data
   if (!is.null(x$y)) {
     p <- ncol(x$X1)
     pch = c(21, 24)
